@@ -68,6 +68,10 @@ ASYNC = 1 << 32
 REPEATED = 1 << 33
 # not repeatable test
 NOT_REPEATABLE = 1 << 34
+# retried test flag
+RETRIED = 1 << 35
+# last retry flag
+LAST_RETRY = 1 << 36
 # expected result
 ERESULT = EOK | EFAIL | ESKIP | EERROR
 # expected any result
@@ -88,7 +92,7 @@ class Flags(object):
             FAIL_NOT_COUNTED, ERROR_NOT_COUNTED, NULL_NOT_COUNTED,
             PAUSE_BEFORE, PAUSE_AFTER, MANUAL, AUTO,
             REPORT, DOCUMENT, MANDATORY, PARALLEL, NO_PARALLEL, CLEAR,
-            ASYNC, REPEATED, NOT_REPEATABLE
+            ASYNC, REPEATED, NOT_REPEATABLE, RETRIED, LAST_RETRY
         ]
     all_str = [
             "TE", "UT", "SKIP", "EOK", "EFAIL", "EERROR", "ESKIP",
@@ -96,7 +100,7 @@ class Flags(object):
             "FAIL_NOT_COUNTED", "ERROR_NOT_COUNTED", "NULL_NOT_COUNTED",
             "PAUSE_BEFORE", "PAUSE_AFTER", "MANUAL", "AUTO",
             "REPORT", "DOCUMENT", "MANDATORY", "PARALLEL", "NO_PARALLEL", "CLEAR",
-            "ASYNC", "REPEATED", "NOT_REPEATABLE"
+            "ASYNC", "REPEATED", "NOT_REPEATABLE", "RETRIED", "LAST_RETRY"
         ]
 
     def __init__(self, flags=0):
